==> aws-java-sdk-ssm-1.9.23-sources.jar: com/amazonaws/services/simplesystemsmanagement/model/transform/DeleteDocumentResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simplesystemsmanagement.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.simplesystemsmanagement.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Delete Document Result JSON Unmarshaller
 */
public class DeleteDocumentResultJsonUnmarshaller implements Unmarshaller<DeleteDocumentResult, JsonUnmarshallerContext> {

    public DeleteDocumentResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        DeleteDocumentResult deleteDocumentResult = new DeleteDocumentResult();

        return deleteDocumentResult;
    }

    private static DeleteDocumentResultJsonUnmarshaller instance;
    public static DeleteDocumentResultJsonUnmarshaller getInstance() {
        if (instance == null) instance = new DeleteDocumentResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-ssm-1.10.15-sources.jar: com/amazonaws/services/simplesystemsmanagement/model/transform/DeleteDocumentResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simplesystemsmanagement.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.simplesystemsmanagement.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * DeleteDocumentResult JSON Unmarshaller
 */
public class DeleteDocumentResultJsonUnmarshaller implements
        Unmarshaller<DeleteDocumentResult, JsonUnmarshallerContext> {

    public DeleteDocumentResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        DeleteDocumentResult deleteDocumentResult = new DeleteDocumentResult();

        return deleteDocumentResult;
    }

    private static DeleteDocumentResultJsonUnmarshaller instance;

    public static DeleteDocumentResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new DeleteDocumentResultJsonUnmarshaller();
        return instance;
    }
}
